PTC10 - Heros Devices 0.8.0 documentation

Skip to content
Back to top
View this page

# PTC10

From: Stanford Research Systems (SRS)

Class: `herosdevices.hardware.srs.ptc10.PTC10`

Driver Quality Index: beta

Driver for the SRS PTC10 programmable temperature controller.

This driver connects via telnet to the ethernet port.

Bold arguments are mandatory. For more information on the listed arguments refer to the class documentation: `herosdevices.hardware.srs.ptc10.PTC10` If parameters appear in this list but not in the class definition, please recursively check the linked base classes for the definition of the parameter.

Argument | Type | Default Value | Description
--- | --- | --- | ---
address | <class ‘str’> |  | IP address of the device.
channels_tc | list | None | None | Names of PTC330 extension cards input channels.
channels_out | list | None | None | Names of the output channels.
macros | dict | None | None | A dict of macros which are written to the temperature controller and can be called with `run_macro()`. The dictionary keys are the names and the values the actual macro code. Note, that the macro content must be a single line string.
observables | dict | None | None | A dictionary of attributes that are emitted with the observable_data event if the device is started as a PolledDatasourceHero. If no values are given, the set temperature, actual temperature and TEC power are emitted.

The following JSON strings can be used to start a HERO device representation of `PTC10` using BOSS.

    {
        "_id": "my_PTC10",
        "classname": "herosdevices.hardware.srs.ptc10.PTC10",
        "arguments": {
            "address": "192.168.1.5",
            "channels_tc": null,
            "channels_out": [
                "WindowOut",
                "OvenOut"
            ],
            "macros": {
                "OvenOn": "if (OvenOut.PID.setpoint==0){ OvenOut.PID.setpoint=50 }else{ popup \"Oven already on\" }"
            },
            "observables": null
        }
    }

generated from signature